@@ -3,11 +3,15 @@ BEGIN {
   $Syccess::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Easy Validation Handler
-$Syccess::VERSION = '0.004';
+$Syccess::VERSION = '0.005';
 use Moo;
 use Module::Runtime qw( use_module );
 use Tie::IxHash;
 
+with qw(
+  MooX::Traits
+);
+
 has validator_namespaces => (
   is => 'lazy',
 );
@@ -37,6 +41,11 @@ sub _build_field_class {
   return 'Syccess::Field';
 }
 
+has field_traits => (
+  is => 'ro',
+  predicate => 1,
+);
+
 has result_class => (
   is => 'lazy',
 );
@@ -45,6 +54,11 @@ sub _build_result_class {
   return 'Syccess::Result';
 }
 
+has result_traits => (
+  is => 'ro',
+  predicate => 1,
+);
+
 has error_class => (
   is => 'lazy',
 );
@@ -53,6 +67,11 @@ sub _build_error_class {
   return 'Syccess::Error';
 }
 
+has error_traits => (
+  is => 'ro',
+  predicate => 1,
+);
+
 has fields_args => (
   is => 'ro',
   predicate => 1,
@@ -84,11 +103,31 @@ sub _build_fields {
   return [ @fields ];
 }
 
+sub field {
+  my ( $self, $name ) = @_;
+  my @field = grep { $_->name eq $name } @{$self->fields};
+  return scalar @field ? $field[0] : undef;
+}
+
+has resulting_field_class => (
+  is => 'lazy',
+  init_arg => undef,
+);
+
+sub _build_resulting_field_class {
+  my ( $self ) = @_;
+  my $field_class = use_module($self->field_class);
+  if ($self->has_field_traits) {
+    $field_class = $field_class->with_traits(@{$self->field_traits});
+  }
+  return $field_class;
+}
+
 sub new_field {
   my ( $self, $name, $validators_list ) = @_;
   my %fields_args = $self->has_fields_args
     ? (%{$self->fields_args}) : ();
-  return use_module($self->field_class)->new(
+  return $self->resulting_field_class->new(
     %fields_args,
     syccess => $self,
     name => $name,
@@ -98,7 +137,11 @@ sub new_field {
 
 sub validate {
   my ( $self, %params ) = @_;
-  return use_module($self->result_class)->new(
+  my $result_class = use_module($self->result_class);
+  if ($self->has_result_traits) {
+    $result_class = $result_class->with_traits(@{$self->result_traits});
+  }
+  return $result_class->new(
     syccess => $self,
     params => { %params },
   );
@@ -121,7 +164,7 @@ Syccess - Easy Validation Handler
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -147,6 +190,15 @@ version 0.004
     }
   }
 
+  my $traitsful_syccess = Syccess->new(
+    result_traits => [qw( MyApp::Syccess::ResultRole )],
+    error_traits => [qw( MyApp::Syccess::ErrorRole )],
+    field_traits => [qw( MyApp::Syccess::FieldRole )],
+    fields => [
+      # ...
+    ],
+  );
+
 =head1 DESCRIPTION
 
 Syccess is developed for L<SyContent|https://sycontent.de/>.
